pub struct ChainTipState {
pub block_hash: Option<CryptoHash>,
pub next_block_height: BlockHeight,
pub num_incoming_bundles: u32,
pub num_operations: u32,
pub num_outgoing_messages: u32,
}Expand description
Block-chaining state.
Fields
block_hash: Option<CryptoHash>Hash of the latest certified block in this chain, if any.
next_block_height: BlockHeightSequence number tracking blocks.
num_incoming_bundles: u32Number of incoming message bundles.
num_operations: u32Number of operations.
num_outgoing_messages: u32Number of outgoing messages.
Implementations
Sourceimpl ChainTipState
impl ChainTipState
pub async fn block_hash(&self, ctx: &Context<'_>) -> Result<&Option<CryptoHash>>
pub async fn next_block_height(&self, ctx: &Context<'_>) -> Result<&BlockHeight>
pub async fn num_incoming_bundles(&self, ctx: &Context<'_>) -> Result<&u32>
pub async fn num_operations(&self, ctx: &Context<'_>) -> Result<&u32>
pub async fn num_outgoing_messages(&self, ctx: &Context<'_>) -> Result<&u32>
Sourceimpl ChainTipState
impl ChainTipState
Sourcepub fn verify_block_chaining(
&self,
new_block: &ProposedBlock,
) -> Result<(), ChainError>
pub fn verify_block_chaining( &self, new_block: &ProposedBlock, ) -> Result<(), ChainError>
Checks that the proposed block is suitable, i.e. at the expected height and with the expected parent.
Sourcepub fn already_validated_block(
&self,
height: BlockHeight,
) -> Result<bool, ChainError>
pub fn already_validated_block( &self, height: BlockHeight, ) -> Result<bool, ChainError>
Returns true if the validated block’s height is below the tip height. Returns an error if
it is higher than the tip.
Sourcepub fn update_counters(
&mut self,
transactions: &[Transaction],
messages: &[Vec<OutgoingMessage>],
) -> Result<(), ChainError>
pub fn update_counters( &mut self, transactions: &[Transaction], messages: &[Vec<OutgoingMessage>], ) -> Result<(), ChainError>
Checks if the measurement counters would be valid.